@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
+  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_stream_alternate.html#a07f36f98c7dcdf435f803e4f0ccaac57',1,'jsStreamAlternate::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
   ['nats_2eh_1',['nats.h',['../nats_8h.html',1,'']]],
   ['nats_5faddress_5fmissing_2',['NATS_ADDRESS_MISSING',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ae1d2c1366dbed428f6589f057acc507d',1,'status.h']]],
   ['nats_5fcheckcompatibility_3',['nats_CheckCompatibility',['../group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e',1,'nats.h']]],
