@@ -4,8 +4,8 @@ var searchData=
   ['sealed_1',['Sealed',['../structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7',1,'jsStreamConfig']]],
   ['sequence_2',['Sequence',['../structjs_msg_meta_data.html#a23d5fd1992033164c73d5c2a16a4e321',1,'jsMsgMetaData::Sequence()'],['../structjs_pub_ack.html#a01d302d5e1a2e71487a8c74c3fed1691',1,'jsPubAck::Sequence()'],['../structjs_direct_get_msg_options.html#a60211d7499cfecdd6e61e6c73af1a2f5',1,'jsDirectGetMsgOptions::Sequence()'],['../structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a0d61e5d3c9c518f455549086ababe7f6',1,'jsOptions::jsOptionsStream::jsOptionsStreamPurge::Sequence()']]],
   ['source_3',['Source',['../structjs_re_publish.html#a1acb593929fd69bbe0f4dc8300dfaeb2',1,'jsRePublish']]],
-  ['sources_4',['Sources',['../structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b',1,'jsStreamConfig::Sources()'],['../structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386',1,'jsStreamInfo::Sources()']]],
-  ['sourceslen_5',['SourcesLen',['../structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a',1,'jsStreamConfig::SourcesLen()'],['../structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672',1,'jsStreamInfo::SourcesLen()']]],
+  ['sources_4',['Sources',['../structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b',1,'jsStreamConfig::Sources()'],['../structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386',1,'jsStreamInfo::Sources()'],['../structkv_config.html#afbfd6725c0b0c9fb661a96c06d788ac9',1,'kvConfig::Sources()']]],
+  ['sourceslen_5',['SourcesLen',['../structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a',1,'jsStreamConfig::SourcesLen()'],['../structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672',1,'jsStreamInfo::SourcesLen()'],['../structkv_config.html#af1d95d5434b10e929d6ce6fa6129a789',1,'kvConfig::SourcesLen()']]],
   ['stallwait_6',['StallWait',['../structjs_options_1_1js_options_publish_async.html#ada58fefe0ed40157b5f5d44b9dd175f9',1,'jsOptions::jsOptionsPublishAsync']]],
   ['state_7',['State',['../structjs_stream_info.html#a766ac56dec3bd19fa5b9861fb5f64397',1,'jsStreamInfo']]],
   ['storage_8',['Storage',['../structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8',1,'jsStreamConfig']]],
