@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
+  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_stream_alternate.html#a07f36f98c7dcdf435f803e4f0ccaac57',1,'jsStreamAlternate::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
   ['nextbysubject_1',['NextBySubject',['../structjs_direct_get_msg_options.html#a16ce7908a3d1690b8ae8bc22350ac238',1,'jsDirectGetMsgOptions']]],
   ['noack_2',['NoAck',['../structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609',1,'jsStreamConfig']]],
   ['nowait_3',['NoWait',['../structjs_fetch_request.html#ae251eebb1998a39fe3b898302b58293d',1,'jsFetchRequest']]],
